==> 0.18.2.tar.gz: lib/components/senior_card/senior_card_widget.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../components/senior_elevated_element/senior_elevated_element.dart';
import '../../components/senior_checkbox/senior_checkbox.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorCard extends StatelessWidget {
  const SeniorCard({
    Key? key,
    required this.child,
    this.pushAction,
    this.showPushIcon = true,
    this.severityColor,
    this.dismissibleConfig,
  }) : super(key: key);

  final Widget child;
  final Function()? pushAction;
  final bool showPushIcon;
  final Color? severityColor;
  final DismissibleConfig? dismissibleConfig;

  factory SeniorCard.checkbox({
    Key key,
    Color? severityColor,
    DismissibleConfig? dismissibleConfig,
    Function() pushAction,
    bool showPushIcon,
    required Widget child,
    required bool value,
    required Function(bool?) onCheck,
  }) = _SeniorCardCheckbox;

  Widget _buildCardContent({
    required Color iconColor,
    required double iconSize,
  }) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        child,
        Visibility(
          visible: showPushIcon && pushAction != null,
          child: Icon(
            FontAwesomeIcons.chevronRight,
            color: iconColor,
            size: iconSize,
          ),
        ),
      ],
    );
  }

  Widget _buildCard({
    required Color color,
    required Color iconColor,
    required double iconSize,
    required double borderRadius,
  }) {
    return SeniorElevatedElement(
      borderRadius: borderRadius,
      elevation: SeniorElevations.dp01,
      child: Material(
        color: Colors.transparent,
        child: InkWell(
          borderRadius: BorderRadius.circular(borderRadius),
          onTap: pushAction,
          child: Ink(
            padding: EdgeInsets.only(left: SeniorSpacing.small),
            decoration: BoxDecoration(
              color: severityColor ?? color,
              borderRadius: BorderRadius.circular(borderRadius),
            ),
            child: Ink(
              padding: const EdgeInsets.only(
                top: SeniorSpacing.normal,
                bottom: SeniorSpacing.normal,
                left: SeniorSpacing.xsmall,
                right: SeniorSpacing.normal,
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.only(
                  topRight: Radius.circular(borderRadius),
                  bottomRight: Radius.circular(borderRadius),
                ),
                color: color,
              ),
              child: _buildCardContent(
                iconColor: iconColor,
                iconSize: iconSize,
              ),
            ),
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    final Color color = theme?.cardTheme?.style?.backgroundColor ??
        defaultTheme.cardTheme?.style?.backgroundColor ??
        SeniorColors.neutralColor100;

    final Color iconColor = theme?.cardTheme?.style?.iconColor ??
        defaultTheme.cardTheme?.style?.iconColor ??
        SeniorColors.neutralColor600;

    final double iconSize = theme?.cardTheme?.iconSize ??
        defaultTheme.cardTheme?.iconSize ??
        SeniorTypographyIconSize.body;

    final double borderRadius = theme?.cardTheme?.borderRadius ??
        defaultTheme.cardTheme?.borderRadius ??
        SeniorRadius.xbig;

    return (dismissibleConfig != null)
        ? Dismissible(
            key: dismissibleConfig!.key,
            onDismissed: (direction) {
              if (direction == DismissDirection.startToEnd) {
                dismissibleConfig!.primaryAction.onDismissed();
              } else if (direction == DismissDirection.endToStart) {
                dismissibleConfig!.secondaryAction != null
                    ? dismissibleConfig!.secondaryAction!.onDismissed()
                    : dismissibleConfig!.primaryAction.onDismissed();
              }
            },
            direction: dismissibleConfig!.secondaryAction != null
                ? DismissDirection.horizontal
                : DismissDirection.startToEnd,
            background: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(borderRadius),
                color: dismissibleConfig!.primaryAction.backgroundColor,
              ),
              child: Padding(
                padding: EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.medium,
                ),
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: FaIcon(
                    dismissibleConfig!.primaryAction.icon,
                    color: SeniorColors.pureWhite,
                    size: SeniorTypographyIconSize.h4,
                  ),
                ),
              ),
            ),
            secondaryBackground: dismissibleConfig!.secondaryAction != null
                ? Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(borderRadius),
                      color: dismissibleConfig!.secondaryAction!.backgroundColor,
                    ),
                    child: Padding(
                      padding: EdgeInsets.symmetric(
                        horizontal: SeniorSpacing.medium,
                      ),
                      child: Align(
                        alignment: Alignment.centerRight,
                        child: FaIcon(
                          dismissibleConfig!.secondaryAction!.icon,
                          color: SeniorColors.pureWhite,
                          size: SeniorTypographyIconSize.h4,
                        ),
                      ),
                    ),
                  )
                : null,
            child: _buildCard(
              color: color,
              iconColor: iconColor,
              iconSize: iconSize,
              borderRadius: borderRadius,
            ),
          )
        : _buildCard(
            color: color,
            iconColor: iconColor,
            iconSize: iconSize,
            borderRadius: borderRadius,
          );
  }
}

class _SeniorCardCheckbox extends SeniorCard {
  _SeniorCardCheckbox({
    Key? key,
    Color? severityColor,
    DismissibleConfig? dismissibleConfig,
    bool showPushIcon = true,
    Function()? pushAction,
    required Widget child,
    required this.value,
    required this.onCheck,
  }) : super(
          key: key,
          child: child,
          showPushIcon: showPushIcon,
          pushAction: pushAction,
          severityColor: severityColor,
          dismissibleConfig: dismissibleConfig,
        );

  final bool value;
  final Function(bool?) onCheck;

  @override
  Widget _buildCardContent({
    required Color iconColor,
    required double iconSize,
  }) {
    return Container(
      child: Stack(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              child,
              Visibility(
                visible: showPushIcon && pushAction != null,
                child: Icon(
                  FontAwesomeIcons.chevronRight,
                  color: iconColor,
                  size: iconSize,
                ),
              ),
            ],
          ),
          Align(
            alignment: Alignment.topRight,
            child: Container(
              width: SeniorCheckbox.size,
              height: SeniorCheckbox.size,
              child: SeniorCheckbox(
                value: value,
                onChanged: onCheck,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

class DismissibleAction {
  final Color backgroundColor;
  final IconData icon;
  final Function() onDismissed;

  const DismissibleAction({
    required this.backgroundColor,
    required this.icon,
    required this.onDismissed,
  });
}

class DismissibleConfig {
  final Key key;
  final DismissibleAction primaryAction;
  final DismissibleAction? secondaryAction;

  const DismissibleConfig({
    required this.key,
    required this.primaryAction,
    this.secondaryAction,
  });
}

==> 0.19.8.tar.gz: lib/components/senior_card/senior_card_widget.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../components/senior_elevated_element/senior_elevated_element.dart';
import '../../components/senior_checkbox/senior_checkbox.dart';
import '../../themes/senior_theme_provider.dart';
import '../../themes/senior_theme.dart';

class SeniorCard extends StatelessWidget {
  /// Creates the SDS card component.
  ///
  /// The parameter [child] is required.
  const SeniorCard({
    Key? key,
    required this.child,
    this.pushAction,
    this.showPushIcon = true,
    this.severityColor,
    this.dismissibleConfig,
  }) : super(key: key);

  /// The contents of the card.
  final Widget child;

  /// Function called when the card is touched.
  /// If this parameter is different from null and the [showPushIcon] parameter is different from false, an icon will be
  /// displayed to the right of the card to indicate that it has an action attached.
  final Function()? pushAction;

  /// Defines whether an icon will be displayed indicating that there is an action attached to the card.
  /// The icon is only displayed if the [pushAction] parameter is different from null.
  ///
  /// The default value is true.
  final bool showPushIcon;

  /// The card's accent color.
  final Color? severityColor;

  /// The dismissible configurations for the card.
  /// Allows you to link actions to card swiping.
  final DismissibleConfig? dismissibleConfig;

  /// Creates the Card component with checkbox.
  ///
  /// The [child], [value] and [onCheck] parameters are required.
  factory SeniorCard.checkbox({
    Key key,
    Color? severityColor,
    DismissibleConfig? dismissibleConfig,
    Function() pushAction,
    bool showPushIcon,
    required Widget child,
    required bool value,
    required Function(bool?) onCheck,
  }) = _SeniorCardCheckbox;

  Widget _buildCardContent({
    required Color iconColor,
    required double iconSize,
  }) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: [
        child,
        Visibility(
          visible: showPushIcon && pushAction != null,
          child: Icon(
            FontAwesomeIcons.chevronRight,
            color: iconColor,
            size: iconSize,
          ),
        ),
      ],
    );
  }

  Widget _buildCard({
    required Color color,
    required Color iconColor,
    required double iconSize,
    required double borderRadius,
  }) {
    return SeniorElevatedElement(
      borderRadius: borderRadius,
      elevation: SeniorElevations.dp01,
      child: Material(
        color: Colors.transparent,
        child: InkWell(
          borderRadius: BorderRadius.circular(borderRadius),
          onTap: pushAction,
          child: Ink(
            padding: EdgeInsets.only(left: SeniorSpacing.small),
            decoration: BoxDecoration(
              color: severityColor ?? color,
              borderRadius: BorderRadius.circular(borderRadius),
            ),
            child: Ink(
              padding: const EdgeInsets.only(
                top: SeniorSpacing.normal,
                bottom: SeniorSpacing.normal,
                left: SeniorSpacing.xxsmall,
                right: SeniorSpacing.normal,
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.only(
                  topRight: Radius.circular(borderRadius),
                  bottomRight: Radius.circular(borderRadius),
                ),
                color: color,
              ),
              child: _buildCardContent(
                iconColor: iconColor,
                iconSize: iconSize,
              ),
            ),
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme = SeniorThemeProvider.getDefaultTheme(context);

    final Color color = theme?.cardTheme?.style?.backgroundColor ??
        defaultTheme.cardTheme?.style?.backgroundColor ??
        SeniorColors.neutralColor100;

    final Color iconColor = theme?.cardTheme?.style?.iconColor ??
        defaultTheme.cardTheme?.style?.iconColor ??
        SeniorColors.neutralColor600;

    final double iconSize = theme?.cardTheme?.iconSize ??
        defaultTheme.cardTheme?.iconSize ??
        SeniorTypographyIconSize.body;

    final double borderRadius = theme?.cardTheme?.borderRadius ??
        defaultTheme.cardTheme?.borderRadius ??
        SeniorRadius.xbig;

    return (dismissibleConfig != null)
        ? Dismissible(
            key: dismissibleConfig!.key,
            onDismissed: (direction) {
              if (direction == DismissDirection.startToEnd) {
                dismissibleConfig!.primaryAction.onDismissed();
              } else if (direction == DismissDirection.endToStart) {
                dismissibleConfig!.secondaryAction != null
                    ? dismissibleConfig!.secondaryAction!.onDismissed()
                    : dismissibleConfig!.primaryAction.onDismissed();
              }
            },
            direction: dismissibleConfig!.secondaryAction != null
                ? DismissDirection.horizontal
                : DismissDirection.startToEnd,
            background: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(borderRadius),
                color: dismissibleConfig!.primaryAction.backgroundColor,
              ),
              child: Padding(
                padding: EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.medium,
                ),
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: FaIcon(
                    dismissibleConfig!.primaryAction.icon,
                    color: SeniorColors.pureWhite,
                    size: SeniorTypographyIconSize.h4,
                  ),
                ),
              ),
            ),
            secondaryBackground: dismissibleConfig!.secondaryAction != null
                ? Container(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(borderRadius),
                      color: dismissibleConfig!.secondaryAction!.backgroundColor,
                    ),
                    child: Padding(
                      padding: EdgeInsets.symmetric(
                        horizontal: SeniorSpacing.medium,
                      ),
                      child: Align(
                        alignment: Alignment.centerRight,
                        child: FaIcon(
                          dismissibleConfig!.secondaryAction!.icon,
                          color: SeniorColors.pureWhite,
                          size: SeniorTypographyIconSize.h4,
                        ),
                      ),
                    ),
                  )
                : null,
            child: _buildCard(
              color: color,
              iconColor: iconColor,
              iconSize: iconSize,
              borderRadius: borderRadius,
            ),
          )
        : _buildCard(
            color: color,
            iconColor: iconColor,
            iconSize: iconSize,
            borderRadius: borderRadius,
          );
  }
}

class _SeniorCardCheckbox extends SeniorCard {
  _SeniorCardCheckbox({
    Key? key,
    Color? severityColor,
    DismissibleConfig? dismissibleConfig,
    bool showPushIcon = true,
    Function()? pushAction,
    required Widget child,
    required this.value,
    required this.onCheck,
  }) : super(
          key: key,
          child: child,
          showPushIcon: showPushIcon,
          pushAction: pushAction,
          severityColor: severityColor,
          dismissibleConfig: dismissibleConfig,
        );

  final bool value;
  final Function(bool?) onCheck;

  @override
  Widget _buildCardContent({
    required Color iconColor,
    required double iconSize,
  }) {
    return Container(
      child: Stack(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              child,
              Visibility(
                visible: showPushIcon && pushAction != null,
                child: Icon(
                  FontAwesomeIcons.chevronRight,
                  color: iconColor,
                  size: iconSize,
                ),
              ),
            ],
          ),
          Align(
            alignment: Alignment.topRight,
            child: Container(
              width: SeniorCheckbox.size,
              height: SeniorCheckbox.size,
              child: SeniorCheckbox(
                value: value,
                onChanged: onCheck,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

class DismissibleAction {
  /// The actions supported by SeniorCard's dismissible configurations.
  ///
  /// The parameters [backgroundColor], [icon] and [onDismissed] are required.
  const DismissibleAction({
    required this.backgroundColor,
    required this.icon,
    required this.onDismissed,
  });

  /// Action background color. Displayed while the card is being dragged.
  final Color backgroundColor;

  /// Action icon.
  final IconData icon;

  /// Function executed when the dismissible action is performed.
  final Function() onDismissed;
}

class DismissibleConfig {
  /// Settings for SeniorCard-supported dismiss action.
  ///
  /// The [key] and [primaryAction] parameters are required.
  const DismissibleConfig({
    required this.key,
    required this.primaryAction,
    this.secondaryAction,
  });

  final Key key;

  /// Primary action. Drag from left to right.
  final DismissibleAction primaryAction;

  /// Secondary action. Drag from right to left.
  final DismissibleAction? secondaryAction;
}
